@@ -31,6 +31,10 @@ int usage(int rc, FILE *fp)
 	      "  mmd PRTAD[:DEVAD]\n"
 	      "    Clause 45 (XMDIO) PHY using address PRTAD:DEVAD.\n"
 	      "\n"
+	      "  mmd-c22 PRTAD[:DEVAD]\n"
+	      "    Clause 45 (XMDIO) PHY addressed over Clause 22 using address\n"
+	      "    PRTAD:DEVAD.\n"
+	      "\n"
 	      "    REG: u16\n"
 	      "\n"
 	      "  mva PHYAD\n"
